==> haskell-unicode-transforms-0.4.0.1-80-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unicode-transforms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unicode-transforms
version:              0.4.0.1
visibility:           public
id:                   unicode-transforms-0.4.0.1-4fjK6ZRbOJjvlYXrVpEBl
key:                  unicode-transforms-0.4.0.1-4fjK6ZRbOJjvlYXrVpEBl
license:              BSD-3-Clause
copyright:
    2016-2017 Harendra Kumar,
    2014–2015 Antonio Nikishaev

maintainer:           harendra.kumar@gmail.com
author:               Harendra Kumar
stability:            Experimental
homepage:             http://github.com/composewell/unicode-transforms
synopsis:             Unicode normalization
description:
    Fast Unicode 14.0.0 normalization in Haskell (NFC, NFKC, NFD, NFKD).

category:             Data,Text,Unicode
abi:                  41a047ed379b9414af3c0be69e5788db
exposed:              True
exposed-modules:
    Data.ByteString.UTF8.Normalize Data.Text.Normalize
    Data.Unicode.Types

hidden-modules:       Data.Unicode.Internal.NormalizeStream
import-dirs:          /usr/lib/ghc-9.2.8/site-local/unicode-transforms-0.4.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/unicode-transforms-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unicode-transforms
hs-libraries:         HSunicode-transforms-0.4.0.1-4fjK6ZRbOJjvlYXrVpEBl
depends:
    base-4.16.4.0 bytestring-0.11.4.0 ghc-prim-0.8.0 text-1.2.5.0
    unicode-data-0.4.0.1-An0e5mpBxuE8PZj3PcKok2

haddock-interfaces:
    /usr/share/doc/haskell-unicode-transforms/html/unicode-transforms.haddock

haddock-html:         /usr/share/doc/haskell-unicode-transforms/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unicode-transforms-0.4.0.1-81-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unicode-transforms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unicode-transforms
version:              0.4.0.1
visibility:           public
id:                   unicode-transforms-0.4.0.1-2Gfs5hz91cPBHh3k7GxH4Y
key:                  unicode-transforms-0.4.0.1-2Gfs5hz91cPBHh3k7GxH4Y
license:              BSD-3-Clause
copyright:
    2016-2017 Harendra Kumar,
    2014–2015 Antonio Nikishaev

maintainer:           harendra.kumar@gmail.com
author:               Harendra Kumar
stability:            Experimental
homepage:             http://github.com/composewell/unicode-transforms
synopsis:             Unicode normalization
description:
    Fast Unicode 14.0.0 normalization in Haskell (NFC, NFKC, NFD, NFKD).

category:             Data,Text,Unicode
abi:                  b8fadd9b4a52fd8ec32c996eb1251565
exposed:              True
exposed-modules:
    Data.ByteString.UTF8.Normalize Data.Text.Normalize
    Data.Unicode.Types

hidden-modules:       Data.Unicode.Internal.NormalizeStream
import-dirs:          /usr/lib/ghc-9.2.8/site-local/unicode-transforms-0.4.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/unicode-transforms-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unicode-transforms
hs-libraries:         HSunicode-transforms-0.4.0.1-2Gfs5hz91cPBHh3k7GxH4Y
depends:
    base-4.16.4.0 bytestring-0.11.4.0 ghc-prim-0.8.0 text-1.2.5.0
    unicode-data-0.4.0.1-FFOYtiNlfD1I5tqmzLThZr

haddock-interfaces:
    /usr/share/doc/haskell-unicode-transforms/html/unicode-transforms.haddock

haddock-html:         /usr/share/doc/haskell-unicode-transforms/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
